DigilockerSdk class

Main SDK class for Surepass DigiLocker verification

Constructors

DigilockerSdk()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

version String
Get SDK version
no setter

Static Methods

setAccentColor(Color color) → void
Set accent color for UI elements
start(BuildContext context, {required String apiToken, Environment environment = Environment.SANDBOX, dynamic onComplete(VerificationResult)?, dynamic onError(String)?}) Future<void>
Start the verification flow