ModelFootprintResponse class

Internal response model for footprint POST endpoint This class is not part of the public API

Constructors

ModelFootprintResponse({ModelFootprintResponseData? data, String? message, String? messageCode, int? statusCode, bool? success})
ModelFootprintResponse.fromJson(Map<String, dynamic> json)
factory

Properties

data ModelFootprintResponseData?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
messageCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final
success bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited