models/options_model library
Classes
- ModelOptions
- Internal response model for /options API endpoint This class is not part of the public API
- OptionsData
- Internal options data containing configuration and user information This class is not part of the public API