OptionsData class

Internal options data containing configuration and user information This class is not part of the public API

Constructors

OptionsData({bool? aadhaarXml, bool? allowSelection, String? clientId, String? email, String? logoUrl, int? maxRetryCount, String? mobile, String? name, String? redirectUrl, bool? skipMainScreen, bool? verifyEmail, bool? verifyPhone, bool? voiceAssistant, String? voiceAssistantLang, String? aadhaarNumber, List<String?>? autoSelectCheckBox})
OptionsData.fromJson(Map<String, dynamic> json)
factory

Properties

aadhaarNumber String?
final
aadhaarXml bool?
final
allowSelection bool?
final
autoSelectCheckBox List<String?>?
final
clientId String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
logoUrl String?
final
maxRetryCount int?
final
mobile String?
final
name String?
final
redirectUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipMainScreen bool?
final
verifyEmail bool?
final
verifyPhone bool?
final
voiceAssistant bool?
final
voiceAssistantLang String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited