GetStatusData class

Status data containing verification state information Internal status data - not part of public API

Constructors

GetStatusData({required bool aadhaarLinked, required bool completed, required int errorCount, required bool failed, required String status})
GetStatusData.fromJson(Map<String, dynamic> json)
factory

Properties

aadhaarLinked bool
final
completed bool
final
errorCount int
final
failed bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited