ModelStatus class

Internal response model for /status API endpoint This class is not part of the public API

Constructors

ModelStatus({required GetStatusData data, required String message, required String messageCode, required int statusCode, required bool success})
ModelStatus.fromJson(Map<String, dynamic> json)
factory

Properties

data GetStatusData
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
messageCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited