VerificationResult class
Result returned after verification is complete
Constructors
-
VerificationResult({required bool success, String? message, Map<
String, dynamic> ? data}) -
VerificationResult.failure({required String message, Map<
String, dynamic> ? data}) -
Create a failure result
factory
-
VerificationResult.success({required String message, Map<
String, dynamic> ? data}) -
Create a success result
factory
Properties
-
data
→ Map<
String, dynamic> ? -
Additional data from the verification process
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
Optional message describing the result
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the verification was successful
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited