ApiService class

Internal service class for handling all API communications with Surepass backend This class is not part of the public API

Constructors

ApiService()

Properties

authToken String?
no setter
baseUrl String
no setter
cachedOptions ModelOptions?
no setter
environment Environment
no setter
hashCode int
The hash code for this object.
no setterinherited
isLoggedIn bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearSession() → void
Clear the persisted token and cached data (logout)
getDigilockerUrl() Future<ModelDigilockerRedirect>
Get DigiLocker redirect URL
getStatus() Future<ModelStatus>
Get verification status after completion
login(String token) Future<ModelOptions>
Login with token using /options endpoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postFootprint(String event) Future<ModelFootprintResponse>
Post footprint event for tracking user journey
setEnvironment(Environment environment) → void
Switch between sandbox and production environments
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited