AppConstants class
Application-wide constants for Surepass SDK Only accentColor is public, all other constants are internal
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- accentColor ↔ Color
-
Public accent color that can be set by users
Default value: #FF9800 (Orange)
getter/setter pair
Constants
- defaultBorderRadius → const double
- errorCheckInterval → const Duration
- iconSize → const double
- lightText → const Color
- loadingDelayDuration → const Duration
- maxAutoFillAttempts → const int
- maxScriptInjectionAttempts → const int
- needHelpButton → const Color
- otpLength → const int
- retryDelay → const Duration
- scriptInjectionDelay → const Duration
- sdkVersion → const String
- surepassLogoPath → const String
- verificationIllustrationPath → const String