models/footprint_model library
Classes
- FootprintData
- Footprint data model Internal footprint data - not part of public API
- ModelFootprintRequest
- Internal request model for posting footprint events This class is not part of the public API
- ModelFootprintResponse
- Internal response model for footprint POST endpoint This class is not part of the public API
- ModelFootprintResponseData
- Data returned in footprint response Internal footprint response data - not part of public API