ModelFootprintRequest class
Internal request model for posting footprint events This class is not part of the public API
Constructors
- ModelFootprintRequest({required String event})
-
ModelFootprintRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited