models/status_model library
Classes
- GetStatusData
- Status data containing verification state information Internal status data - not part of public API
- ModelStatus
- Internal response model for /status API endpoint This class is not part of the public API