JavaScriptInjector class

Internal utility class for generating JavaScript code to inject into DigiLocker WebView This class is not part of the public API

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAutoFillScript(String aadhaarNumber, List<String?>? autoSelectCheckBox) String
Generate comprehensive auto-fill script for DigiLocker